""" 初始化 设定值"""

from llmada import BianXieAdapter
from .utils import Setting, load_config, Date
# Load configuration
config = load_config()
KANBAN_PATH = config.get('KANBAN_PATH', '')
WORK_CANVAS_PATH = config.get('WORK_CANVAS_PATH', [])

setting = Setting()
llm = BianXieAdapter()
llm.set_model("gpt-4.1")
setting.llm = llm
setting.debug = True

Date()